-- ===================================================
-- Constants
-- ===================================================

local ADDON_NAME, Mocksamdi = ...;
local GENERAL_SOUNDS = Mocksamdi.GENERAL_SOUNDS;
local CLASS_SOUNDS = Mocksamdi.CLASS_SOUNDS;

-- ===================================================
-- Variables
-- ===================================================

local lastPlayedSoundIndex = 0;

-- ===================================================
-- Local Functions
-- ===================================================

-- Get class specific sound
local getClassSound = function (classId)
	if classId == 1 then return CLASS_SOUNDS.WARIROR;
	elseif classId == 2  then return CLASS_SOUNDS.PALADIN;
	elseif classId == 3  then return CLASS_SOUNDS.HUNTER;
	elseif classId == 4  then return CLASS_SOUNDS.ROGUE;
	elseif classId == 5  then return CLASS_SOUNDS.PRIEST;
	elseif classId == 6  then return CLASS_SOUNDS.DEATH_KNIGHT;
	elseif classId == 7  then return CLASS_SOUNDS.SHAMEN;
	elseif classId == 8  then return CLASS_SOUNDS.MAGE;
	elseif classId == 9  then return CLASS_SOUNDS.WARLOCK;
	elseif classId == 10 then return CLASS_SOUNDS.MONK;
	elseif classId == 11 then return CLASS_SOUNDS.DRUID;
	elseif classId == 12 then return CLASS_SOUNDS.DEMON_HUNTER;
	end

	-- fallback
	Mocksamdi:printDebug("ClassId was " .. classId);
	return 94633;
end

-- ===================================================
-- Global Functions
-- ===================================================

-- Play mock sounds
function Mocksamdi:playMockSound ()
	local soundCount = table.getn(GENERAL_SOUNDS);
	local totalSoundCount = soundCount;

	-- if they turned it off then bail now
	if not MocksamdiPlayAudio then
		return false;
	end

	-- load class and add the class specific one to the rotation
	local localizedClass, englishClass, classIndex = UnitClass("player");
	if classIndex > 0 then
		totalSoundCount = soundCount + 1;
	end

	local soundIndex = math.random(1, totalSoundCount);

	-- lazy dedupe (you should probably make this better and store an array)
	if soundIndex == lastPlayedSoundIndex then
		Mocksamdi:printDebug("Dupe sound " .. soundIndex .. ". Picking another");
		soundIndex = soundIndex + 1;
	end
	lastPlayedSoundIndex = soundIndex; -- store the new played sound

	Mocksamdi:printDebug("Picked random number " .. soundIndex .. " of " .. totalSoundCount);

	if soundIndex > soundCount then
		local classSound = getClassSound(classIndex)
		Mocksamdi:printDebug("Playing class sound " .. classSound);
		PlaySound(classSound);
		return;
	end

	Mocksamdi:printDebug("Playing sound " .. GENERAL_SOUNDS[soundIndex]);
	PlaySound(GENERAL_SOUNDS[soundIndex]);
end
